@@ -44,15 +44,19 @@ def general_request(method: str, url: str, **kwargs) -> str:
         return r.text
     except ConnectionError as exc:
         error_type = str(exc)
+        logging.error('Netowork error (DNS, refused connection, etc)')
         raise Exception("Netowork error (DNS, refused connection, etc)")
     except HTTPError as exc:
         error_type = str(exc)
+        logging.error(f"{r.status_code} {r.reason}")
         raise Exception(f"{r.status_code} {r.reason}")
     except TimeoutError as exc:
         error_type = str(exc)
+        logging.error("Timeout error from API")
         raise Exception("Timeout error from API")
     except RequestException as exc:
         error_type = str(exc)
+        logging.error("General error in getting data from API")
         raise Exception("General error in getting data from API")
 
 
@@ -103,6 +107,7 @@ def __create_sql_query(table_name, data: List[Dict[str, Any]]) -> str:
         str: query
     """
     if not isinstance(table_name, str):
+        logging.error(f"The name of the table must be a string, and {table_name} is a {type(table_name)}")
         raise ValueError(
             f"The name of the table must be a string, and {table_name} is a {type(table_name)}"
         )
